Plotting
========

.. currentmodule:: hpipy.utils.plotting

.. autosummary::
   :toctree: _autosummary
   :template: class.rst

   plot_index
   plot_index_accuracy
   plot_index_volatility
   plot_series
   plot_series_accuracy
   plot_series_volatility
   plot_series_revision
